@@ -323,7 +323,7 @@ def parent_children_sections(
     doc = {}
     has_parents = {}
 
-    for parent in data['parent_data']['issues']:
+    for parent in data['parent_data']['data']['issues']:
         p_id = parent['id']
         p_key = parent['key']
 
@@ -372,7 +372,7 @@ def parent_children_sections(
                 has_parents[c_key] = []
             has_parents[c_key].append(p_key)
 
-    for child in data['children_data']['issues']:
+    for child in data['children_data']['data']['issues']:
         c_id = child['id']
         c_key = child['key']
 
@@ -380,7 +380,7 @@ def parent_children_sections(
 
         p_key = c_field['parent']['key']
         # assert p_key in has_parents[c_key]
-        p_itn = c_field['parent']['issuetype']['name']
+        # p_itn = c_field['parent']['issuetype']['name']
         # assert p_itn == parent_type_name
 
         c_itn = c_field['issuetype']['name']
@@ -402,31 +402,35 @@ def doc_to_markdown(doc, parent_type_name: str, children_type_name: str) -> str:
     """Transform the document content to markdown."""
     md = []
     for p_key, p_tree in doc.items():
-        p_head = f'## {parent_type_name} {p_tree["summary"].title()} ({p_key})'.strip(LF)
+        p_head = f'## {p_tree["summary"]}'.strip().strip(LF)
         c_count = len(p_tree['children'])
         c_type_disp = f'{children_type_name}{"" if c_count == 1 else "s"}'
         p_para = f'The {p_tree["type"]} consists of {c_count} {c_type_disp}'.strip(LF)
 
         c_parts = []
-        double_pipe = '||'
+        double_pipe, ast_pipe, pipe_ast = '||', '|*', '*|'
+        nbsp = '&nbsp;'
         for c_key, c_data in p_tree['children'].items():
-            c_head = f'### {children_type_name} {c_data["summary"].title()} ({c_key})'.strip(LF)
-            c_content = LF.join(line for line in c_data['description'].strip(LF).split(LF) if line)
-            if double_pipe in c_content:
-                # patch confluence markdown like table heads ...
-                c_patch = []
-                c_content_lines = c_content.split(LF)
-                for line in c_content_lines:
+            c_head = f'### {c_data["summary"]}'.strip().strip(LF)
+            c_in = [line for line in c_data['description'].replace(nbsp, ' ').strip().split(LF)]
+            c_out = []
+            for line in c_in:
+                if line.startswith(double_pipe) or line.startswith(ast_pipe):
+                    # patch confluence markdown like table heads ...
                     line_s = line.strip()
                     extra_line = ''
                     if line_s.startswith(double_pipe) and line_s.endswith(double_pipe):
-                        lp = line.replace(double_pipe, '|')
-                        extra_line = ''.join(c if c == '|' else '-' for c in lp).replace('|-', '|:').replace('-|', ' |')
-                    c_patch.append(line)
+                        line = line.replace(double_pipe, '|')
+                        extra_line = ''.join(c if c == '|' else '-' for c in line).replace('|-', '|:').replace('-|', ' |')
+                    elif line_s.startswith(ast_pipe) and line_s.endswith(pipe_ast):
+                        extra_line = ''.join(c if c == '|' else '-' for c in line).replace('|-', '|:').replace('-|', ' |')
+                    c_out.append(line)
                     if extra_line:
-                        c_patch.append(extra_line)
-                c_content = LF.join(c_patch)
-            c_parts.extend([LF, c_head, LF, c_content])
+                        c_out.append(extra_line)
+                else:
+                    c_out.append(line)
+
+            c_parts.extend([LF, c_head, LF, *c_out])
 
         md.extend([LF, p_head, LF, p_para])
         md.extend(c_parts)
