@@ -17,20 +17,17 @@ def report(shallow: bool = False) -> str:
             sys.stdout.write('\nInfo: No setuptools module found and shallow reporting requested. Continuing ...')
         else:
             message = (
-                '\n  Report requires setuptools (to identify the version of antlr4 and atlassian-python-api).'
+                '\n  Report requires setuptools (to identify the version of atlassian-python-api).'
                 '\n  You may either add --shallow or install the module via `pip install setuptools`\n\n'
             )
             return message
 
     if deep:
-        import antlr4  # type: ignore
         import atlassian  # type: ignore # noqa
 
         packages = pkg_resources.working_set  # noqa
         monkey_atl = [p.version for p in packages if p.project_name == 'atlassian-python-api'][0]  # noqa
         atlassian.__version__ = monkey_atl
-        monkey_ant = [p.version for p in packages if p.project_name == 'antlr4-python3-runtime'][0]  # noqa
-        antlr4.__version__ = monkey_ant
 
     class Report(scooby.Report):  # type: ignore
         def __init__(self, additional=None, ncol=3, text_width=80, sort=False):
@@ -39,7 +36,6 @@ def report(shallow: bool = False) -> str:
             # Mandatory packages.
             core = [
                 'laskea',
-                'antlr4',  # has version in METADATA text file in package info only?
                 'atlassian',  # has version in VERSION text file in package info only?
                 'cogapp.cogapp',
                 'jmespath',
